@@ -1,6 +1,6 @@
 package Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::CRUD;
 {
-  $Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::CRUD::VERSION = '2.122460';
+  $Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::CRUD::VERSION = '2.123270';
 }
 
 use strict;
@@ -463,7 +463,9 @@ sub _create_update_core {
                 $f => $proxy_updates->{$rel}->{$f}
             });
         }
-        $self_row->$rel->update; # save it
+        $self_row->result_source->schema->txn_do(
+            sub { $self_row->$rel->update }
+        ); # save it
     }
 
     if ($ENV{AUTOCRUD_DEBUG} and $c->debug) {
@@ -471,7 +473,9 @@ sub _create_update_core {
         $c->log->debug( Dumper $params );
     }
 
-    return $self_row->in_storage ? $self_row->update : $self_row->insert;
+    return $self_row->result_source->schema->txn_do(sub {
+        $self_row->in_storage ? $self_row->update : $self_row->insert
+    });
 }
 
 sub delete {
@@ -487,7 +491,8 @@ sub delete {
     }
     my $row = eval { $c->model($meta->extra('model'))->find($filter) };
 
-    if (blessed $row and eval {$row->delete}) {
+    if (blessed $row
+        and eval { $row->result_source->schema->txn_do(sub { $row->delete }) }) {
         $response->{'success'} = 1;
     }
 
